Directory

Struct Directory 

pub struct Directory { /* private fields */ }

Implementations

Source

impl Directory

pub fn new(root: &Path, ignore: bool) -> Result<Self, Error>

pub fn new_with_empty_body(root: &Path, ignore: bool) -> Result<Self, Error>

pub fn print_body(&self) -> Result<(), Error>

Wrapper function to print Directory body’s structure.

pub fn fast_print_body(&self) -> Result<(), Error>

For printing from an empty directory state when concerned about speed. We output the tree as we traverse our directory tree.